@@ -1,4 +1,4 @@
-# $Id$
+# $Id: FixedKeys.pm,v 1.10 2006/06/01 18:59:12 dave Exp $
 
 =head1 NAME
 
@@ -62,18 +62,17 @@ This module is left on CPAN as an example of tied hashes.
 
 package Tie::Hash::FixedKeys; 
 
-use 5.006;
 use strict;
-use warnings;
 
 use Tie::Hash;
 use Carp;
+use vars qw(@ISA $VERSION);
 
 use Attribute::Handlers autotie => { "__CALLER__::FixedKeys" => __PACKAGE__ };
 
-our @ISA = qw(Tie::StdHash);
+@ISA = qw(Tie::StdHash);
 
-our $VERSION = '1.13.2';
+$VERSION = sprintf "%d.%02d", '$Revision: 1.10 $ ' =~ /(\d+)\.(\d+)/;
 
 =head1 METHODS
 
@@ -146,7 +145,7 @@ __END__
 
 Dave Cross <dave@mag-sol.com>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT
 
 Copyright (C) 2001, Magnum Solutions Ltd.  All Rights Reserved.
 
@@ -158,3 +157,31 @@ modify it under the same terms as Perl itself.
 perl(1), perltie(1).
 
 =cut
+   
+#
+# $Log: FixedKeys.pm,v $
+# Revision 1.10  2006/06/01 18:59:12  dave
+# Added note about Hash::Util::lock_keys.
+#
+# Revision 1.9  2005/10/22 21:29:58  dave
+# Added pod coverage tests.
+#
+# Revision 1.8  2004/10/23 16:05:19  dave
+# Improved test coverage.
+#
+# Revision 1.7  2002/09/23 19:00:32  dave
+# Fixed to work under 5.8.0.
+#
+# Revision 1.6  2002/07/12 18:34:28  dave
+# Corrected Attirbute::Handlers dependency
+#
+# Revision 1.5  2001/12/09 18:54:42  dave
+# Added Attribute::Handlers interface.
+#
+# Revision 1.4  2001/09/03 20:03:53  dave
+# Minor fixes.
+#
+# Revision 1.3  2001/09/02 16:55:18  dave
+# Added RCS headers
+#
+
